==> jc-1.4.0.tar.gz: gnu/java/rmi/RMIMarshalledObjectInputStream.h <==
// public class gnu.java.rmi.RMIMarshalledObjectInputStream

// class file dependencies
// @dep_class 7e58d923b91cc56f gnu_java_rmi_RMIMarshalledObjectInputStream
// @dep_class 2da16ed0039378d9 gnu_java_rmi_server_RMIObjectInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 4008cd22e279a8c3 java_io_ObjectInputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_rmi_server_RMIObjectInputStream

#include "gnu/java/rmi/server/RMIObjectInputStream.h"

#ifndef _JC_gnu_java_rmi_RMIMarshalledObjectInputStream_H_
#define _JC_gnu_java_rmi_RMIMarshalledObjectInputStream_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_refs	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_refs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_nonrefs	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$refs	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$refs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$nonrefs	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$nonrefs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object;

typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vmethods	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vmethods;
typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtable	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtable;
typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype;

// Constructors
extern void _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$method$_init$40935bfdbc71da56(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object *, struct _jc_byte_array *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$method$getAnnotation$74e25509df28bb55(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$method_info$getAnnotation$74e25509df28bb55;

// Virtual methods structure
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vmethods {
	struct _jc_java_lang_Object$object	*(*getAnnotation$74e25509df28bb55)(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object *);
};

// Vtable
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ObjectInputStream$vmethods	java_io_ObjectInputStream;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods	gnu_java_rmi_server_RMIObjectInputStream;
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vmethods	gnu_java_rmi_RMIMarshalledObjectInputStream;
};

// Vtype
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_refs {
	struct _jc_java_io_ObjectInputStream$object	*locStream;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$refs {
    _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_refs	gnu_java_rmi_RMIMarshalledObjectInputStream;
    _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs	gnu_java_rmi_server_RMIObjectInputStream;
    _jc_java_io_ObjectInputStream$sub_refs	java_io_ObjectInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ObjectInputStream$sub_nonrefs	java_io_ObjectInputStream;
    _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs	gnu_java_rmi_server_RMIObjectInputStream;
    _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_nonrefs	gnu_java_rmi_RMIMarshalledObjectInputStream;
};

// Object instance structure
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object {
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype	*vtype;
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_RMIMarshalledObjectInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$class_object;

#endif	/* _JC_gnu_java_rmi_RMIMarshalledObjectInputStream_H_ */

==> jc-1.4.5.tar.gz: gnu/java/rmi/RMIMarshalledObjectInputStream.h <==
// public class gnu.java.rmi.RMIMarshalledObjectInputStream

// class file dependencies
// @dep_class e918ccec29838be9 gnu_java_rmi_RMIMarshalledObjectInputStream
// @dep_class 2da16ed0039378d9 gnu_java_rmi_server_RMIObjectInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class d8257ba70d6d4735 java_io_ObjectInputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_rmi_server_RMIObjectInputStream

#include "gnu/java/rmi/server/RMIObjectInputStream.h"

#ifndef _JC_gnu_java_rmi_RMIMarshalledObjectInputStream_H_
#define _JC_gnu_java_rmi_RMIMarshalledObjectInputStream_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_refs	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_refs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_nonrefs	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$refs	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$refs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$nonrefs	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$nonrefs;
typedef struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object;

typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vmethods	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vmethods;
typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtable	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtable;
typedef const struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype;

// Constructors
extern void _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$method$_init$40935bfdbc71da56(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object *, struct _jc_byte_array *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$method$getAnnotation$74e25509df28bb55(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$method_info$getAnnotation$74e25509df28bb55;

// Virtual methods structure
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vmethods {
	struct _jc_java_lang_Object$object	*(*getAnnotation$74e25509df28bb55)(_jc_env *, struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ObjectInputStream$vmethods	java_io_ObjectInputStream;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods	gnu_java_rmi_server_RMIObjectInputStream;
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vmethods	gnu_java_rmi_RMIMarshalledObjectInputStream;
};

// Vtype
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_refs {
	struct _jc_java_io_ObjectInputStream$object	*locStream;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$refs {
    _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_refs	gnu_java_rmi_RMIMarshalledObjectInputStream;
    _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs	gnu_java_rmi_server_RMIObjectInputStream;
    _jc_java_io_ObjectInputStream$sub_refs	java_io_ObjectInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ObjectInputStream$sub_nonrefs	java_io_ObjectInputStream;
    _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs	gnu_java_rmi_server_RMIObjectInputStream;
    _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$sub_nonrefs	gnu_java_rmi_RMIMarshalledObjectInputStream;
};

// Object instance structure
struct _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$object {
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype	*vtype;
	_jc_gnu_java_rmi_RMIMarshalledObjectInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$vtype _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_RMIMarshalledObjectInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_RMIMarshalledObjectInputStream$class_object;

#endif	/* _JC_gnu_java_rmi_RMIMarshalledObjectInputStream_H_ */
